==> CloudClientStandardAWS_v2.0.0.zip: com/clustercontrol/ws/cloud/CreateInstanceByTemplateRequest.java <==

package com.clustercontrol.ws.cloud;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>createInstanceByTemplateRequest complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="createInstanceByTemplateRequest">
 *   &lt;complexContent>
 *     &lt;extension base="{http://cloud.ws.clustercontrol.com}cloudRequest">
 *       &lt;sequence>
 *         &lt;element name="arguments" type="{http://cloud.ws.clustercontrol.com}templateJobsArgument" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="flavor" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="instanceDetail" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="nodeDetail" type="{http://cloud.ws.clustercontrol.com}nodeDetail" minOccurs="0"/>
 *         &lt;element name="tags" type="{http://cloud.ws.clustercontrol.com}tag" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="templateId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="zone" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "createInstanceByTemplateRequest", propOrder = {
    "arguments",
    "flavor",
    "instanceDetail",
    "nodeDetail",
    "tags",
    "templateId",
    "zone"
})
public class CreateInstanceByTemplateRequest
    extends CloudRequest
{

    @XmlElement(nillable = true)
    protected List<TemplateJobsArgument> arguments;
    protected String flavor;
    protected String instanceDetail;
    protected NodeDetail nodeDetail;
    @XmlElement(nillable = true)
    protected List<Tag> tags;
    protected String templateId;
    protected String zone;

    /**
     * Gets the value of the arguments property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the arguments property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getArguments().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TemplateJobsArgument }
     * 
     * 
     */
    public List<TemplateJobsArgument> getArguments() {
        if (arguments == null) {
            arguments = new ArrayList<TemplateJobsArgument>();
        }
        return this.arguments;
    }

    /**
     * flavorプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFlavor() {
        return flavor;
    }

    /**
     * flavorプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFlavor(String value) {
        this.flavor = value;
    }

    /**
     * instanceDetailプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceDetail() {
        return instanceDetail;
    }

    /**
     * instanceDetailプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceDetail(String value) {
        this.instanceDetail = value;
    }

    /**
     * nodeDetailプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link NodeDetail }
     *     
     */
    public NodeDetail getNodeDetail() {
        return nodeDetail;
    }

    /**
     * nodeDetailプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link NodeDetail }
     *     
     */
    public void setNodeDetail(NodeDetail value) {
        this.nodeDetail = value;
    }

    /**
     * Gets the value of the tags property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tags property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTags().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Tag }
     * 
     * 
     */
    public List<Tag> getTags() {
        if (tags == null) {
            tags = new ArrayList<Tag>();
        }
        return this.tags;
    }

    /**
     * templateIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemplateId() {
        return templateId;
    }

    /**
     * templateIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemplateId(String value) {
        this.templateId = value;
    }

    /**
     * zoneプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getZone() {
        return zone;
    }

    /**
     * zoneプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setZone(String value) {
        this.zone = value;
    }

}

==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/CreateInstanceByTemplateRequest.java <==

package com.clustercontrol.ws.cloud;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>createInstanceByTemplateRequest complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="createInstanceByTemplateRequest">
 *   &lt;complexContent>
 *     &lt;extension base="{http://cloud.ws.clustercontrol.com}cloudRequest">
 *       &lt;sequence>
 *         &lt;element name="arguments" type="{http://cloud.ws.clustercontrol.com}templateJobsArgument" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="flavor" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="instanceDetail" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="nodeDetail" type="{http://cloud.ws.clustercontrol.com}nodeDetail" minOccurs="0"/>
 *         &lt;element name="tags" type="{http://cloud.ws.clustercontrol.com}tag" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="templateId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="zone" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "createInstanceByTemplateRequest", propOrder = {
    "arguments",
    "flavor",
    "instanceDetail",
    "nodeDetail",
    "tags",
    "templateId",
    "zone"
})
public class CreateInstanceByTemplateRequest
    extends CloudRequest
{

    @XmlElement(nillable = true)
    protected List<TemplateJobsArgument> arguments;
    protected String flavor;
    protected String instanceDetail;
    protected NodeDetail nodeDetail;
    @XmlElement(nillable = true)
    protected List<Tag> tags;
    protected String templateId;
    protected String zone;

    /**
     * Gets the value of the arguments property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the arguments property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getArguments().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TemplateJobsArgument }
     * 
     * 
     */
    public List<TemplateJobsArgument> getArguments() {
        if (arguments == null) {
            arguments = new ArrayList<TemplateJobsArgument>();
        }
        return this.arguments;
    }

    /**
     * flavorvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFlavor() {
        return flavor;
    }

    /**
     * flavorvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFlavor(String value) {
        this.flavor = value;
    }

    /**
     * instanceDetailvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInstanceDetail() {
        return instanceDetail;
    }

    /**
     * instanceDetailvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInstanceDetail(String value) {
        this.instanceDetail = value;
    }

    /**
     * nodeDetailvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link NodeDetail }
     *     
     */
    public NodeDetail getNodeDetail() {
        return nodeDetail;
    }

    /**
     * nodeDetailvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link NodeDetail }
     *     
     */
    public void setNodeDetail(NodeDetail value) {
        this.nodeDetail = value;
    }

    /**
     * Gets the value of the tags property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tags property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTags().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Tag }
     * 
     * 
     */
    public List<Tag> getTags() {
        if (tags == null) {
            tags = new ArrayList<Tag>();
        }
        return this.tags;
    }

    /**
     * templateIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemplateId() {
        return templateId;
    }

    /**
     * templateIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemplateId(String value) {
        this.templateId = value;
    }

    /**
     * zonevpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getZone() {
        return zone;
    }

    /**
     * zonevpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setZone(String value) {
        this.zone = value;
    }

}
